@@ -57,6 +57,7 @@ def export_one(instance, obj, br):
     export_file = '%s/%s.zexp' % (export_folder, obj)
 
     cmd = 'rm -f %s' % export_file
+    host_name = instance['host']
     if host_name != 'localhost':
         cmd = 'ssh %s@%s %s' % (instance['user'], host_name, cmd)
     os.system(cmd)
@@ -192,3 +193,19 @@ def submit_url(instance, url, args, out_file, br):
     fp = open(out_file, "a")
     fp.write(br.contents)
     fp.close()
+
+def get_db_size(lines):
+    """ gets the size of the db """
+    lines = [ x.strip() for x in lines.split('\n') ]
+    start = lines.index('Database Size')
+    return lines[start + 5]
+
+def pack_db(instance, db_name, br):
+    url = 'http://%s:%s/Control_Panel/Database/%s/manage_main' % (instance['host'],
+              instance['port'], db_name)
+    br.open(url)
+    old_sz = get_db_size(br.contents)
+    br.getForm().submit()
+    new_sz = get_db_size(br.contents)
+    return old_sz, new_sz
+
