@@ -1,4 +1,30 @@
 from StringIO import StringIO
+
+def chk_editor(self):
+    out = StringIO()
+    mtool = self.portal_membership
+    dtool = self.portal_memberdata
+    props = dtool.propertyIds()
+    for mem_id in mtool.listMemberIds():
+        mem = mtool.getMemberById(mem_id)
+        if mem.getProperty('wysiwyg_editor') != 'TinyMCE':
+            print >> out, 'Bad editor', mem.getProperty('wysiwyg_editor'), ' for member', mem_id
+    print >> out, 'Done'
+    return out.getvalue()
+
+def chg_editor(self):
+    out = StringIO()
+    mtool = self.portal_membership
+    dtool = self.portal_memberdata
+    props = dtool.propertyIds()
+    last_props = {}
+    last_props['wysiwyg_editor'] = 'TinyMCE'
+    for mem_id in mtool.listMemberIds():
+        mem = mtool.getMemberById(mem_id)
+        mem.setMemberProperties(last_props)
+    print >> out, 'Done'
+    return out.getvalue()
+
 def load_memberdata(self):
     out = StringIO()
     mtool = self.portal_membership
