@@ -13,6 +13,34 @@ from zope.component.interfaces import ComponentLookupError
 from contentratings.interfaces import IEditorRatable, IUserRatable, IUserRating, IEditorialRating
 from Products.ATContentTypes.content.schemata import finalizeATCTSchema
 
+def enable_link_integrity(self, enable):
+    out = StringIO()
+    props = self.portal_properties.site_properties
+    props.manage_changeProperties(enable_link_integrity_checks=(enable=='True'))
+    print >> out, props.getProperty('enable_link_integrity_checks')
+    return out.getvalue()
+
+def chg_catalog_icon(self):
+    out = StringIO()
+    pc = self.portal_catalog
+    res = pc(portal_type='FeedFeederItem')
+    res = ( o.getObject() for o in res if o.getIcon == 'folder_icon.gif' and o.getObject() )
+    cnt = 0
+    for obj in res:
+        obj.reindexObject(idxs=[])
+        cnt += 1
+    print >> out, cnt, 'objects updated'
+    return out.getvalue()
+
+def enable_syndication(self, obj):
+    """ enable syndication """
+    tool = self.portal_syndication
+    obj = self.restrictedTraverse(obj)
+    #tool.enableSyndication(obj)
+    #ob1 = getattr(obj, 'syndication_information')
+    #return ob1.absolute_url()
+    return tool.isSyndicationAllowed(obj)
+
 def show_fieldsets(self):
     """ this fixes schema of old documents """
     out = StringIO()
